"use strict";
var LitJsSdk_litStorage = (() => {
  var __defProp = Object.defineProperty;
  var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
  var __getOwnPropNames = Object.getOwnPropertyNames;
  var __hasOwnProp = Object.prototype.hasOwnProperty;
  var __export = (target, all) => {
    for (var name in all)
      __defProp(target, name, { get: all[name], enumerable: true });
  };
  var __copyProps = (to, from, except, desc) => {
    if (from && typeof from === "object" || typeof from === "function") {
      for (let key of __getOwnPropNames(from))
        if (!__hasOwnProp.call(to, key) && key !== except)
          __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
    }
    return to;
  };
  var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

  // packages/lit-storage/src/index.ts
  var src_exports = {};
  __export(src_exports, {
    LitNodejsStorage: () => LitNodejsStorage,
    LitStorage: () => LitStorage
  });

  // packages/lit-storage/src/lib/lit-nodejs-storage.ts
  var LitNodejsStorage = class {
    constructor() {
      this.storage = {};
    }
    get length() {
      return Object.keys(this.storage).length;
    }
    clear() {
      this.storage = {};
    }
    getItem(key) {
      const item = this.storage[key];
      return item || null;
    }
    key(index) {
      const keys = Object.keys(this.storage);
      return keys[index] || null;
    }
    removeItem(key) {
      delete this.storage[key];
    }
    setItem(key, value) {
      this.storage[key] = value;
    }
  };

  // packages/lit-storage/src/lib/lit-storage.ts
  var LitStorage = class {
    constructor({ storageProvider } = {}) {
      this.keys = {
        autoAuth: "lit-auto-auth"
      };
      if (storageProvider && Object.keys(storageProvider).length > 0) {
        this.storage = storageProvider;
      } else if (typeof window !== "undefined") {
        this.storage = window.localStorage;
      } else {
        this.storage = new LitNodejsStorage();
      }
    }
    get length() {
      return this.storage.length;
    }
    clear() {
      return this.storage.clear();
    }
    getItem(key) {
      return this.storage.getItem(key);
    }
    getAllItems() {
      const items = {};
      for (let i = 0; i < this.storage.length; i++) {
        const key = this.storage.key(i);
        if (key) {
          const item = this.storage.getItem(key);
          if (item) {
            items[key] = item;
          }
        }
      }
      return items;
    }
    key(index) {
      return this.storage.key(index);
    }
    removeItem(key) {
      return this.storage.removeItem(key);
    }
    setItem(key, value) {
      return this.storage.setItem(key, value);
    }
    isExpired(key) {
      const itemStr = this.storage.getItem(key);
      if (!itemStr)
        return true;
      const item = JSON.parse(itemStr);
      if (item && item.expirationDate) {
        const expirationDate = new Date(item.expirationDate);
        return /* @__PURE__ */ new Date() > expirationDate;
      }
      return false;
    }
    // -- extra functions
    setExpirableItem(key, value, duration, unit) {
      const expirationDate = /* @__PURE__ */ new Date();
      switch (unit) {
        case "seconds":
          expirationDate.setSeconds(expirationDate.getSeconds() + duration);
          break;
        case "minutes":
          expirationDate.setMinutes(expirationDate.getMinutes() + duration);
          break;
        case "hours":
          expirationDate.setHours(expirationDate.getHours() + duration);
          break;
        case "days":
          expirationDate.setDate(expirationDate.getDate() + duration);
          break;
        default:
          throw new Error(`Invalid unit of time: ${unit}`);
      }
      const item = {
        value,
        expirationDate: expirationDate.toJSON()
      };
      return this.storage.setItem(key, JSON.stringify(item));
    }
    getExpirableItem(key) {
      const itemStr = this.storage.getItem(key);
      if (!itemStr)
        return null;
      const item = JSON.parse(itemStr);
      if (item && item.expirationDate) {
        const expirationDate = new Date(item.expirationDate);
        if (/* @__PURE__ */ new Date() > expirationDate) {
          this.storage.removeItem(key);
          return null;
        }
        return item.value;
      }
      return null;
    }
    isItemExpired(key) {
      const itemStr = this.storage.getItem(key);
      if (!itemStr)
        return true;
      const item = JSON.parse(itemStr);
      if (item && item.expirationDate) {
        const expirationDate = new Date(item.expirationDate);
        return /* @__PURE__ */ new Date() > expirationDate;
      }
      return false;
    }
    // -- convert expirable to ISO string
    convertToISOString(expirationLength, expirationUnit) {
      let multiplier;
      const unit = expirationUnit.endsWith("s") ? expirationUnit.slice(0, -1) : expirationUnit;
      switch (unit) {
        case "second":
          multiplier = 1e3;
          break;
        case "minute":
          multiplier = 1e3 * 60;
          break;
        case "hour":
          multiplier = 1e3 * 60 * 60;
          break;
        case "day":
          multiplier = 1e3 * 60 * 60 * 24;
          break;
        case "week":
          multiplier = 1e3 * 60 * 60 * 24 * 7;
          break;
        case "month":
          multiplier = 1e3 * 60 * 60 * 24 * 30;
          break;
        case "year":
          multiplier = 1e3 * 60 * 60 * 24 * 365;
          break;
        default:
          throw new Error(`Invalid unit of time: ${expirationUnit}`);
      }
      return new Date(Date.now() + multiplier * expirationLength).toISOString();
    }
  };
  return __toCommonJS(src_exports);
})();
//# sourceMappingURL=lit-storage.js.map
